import * as sqs from '@aws-cdk/aws-sqs';
import * as cdk from '@aws-cdk/core';
export interface MonitoredQueueProps {
    /**
     * Queue settings as in sqs.QueueProps, deadLetterQueue property is ignored
     */
    readonly queueSettings: sqs.QueueProps;
    /**
     * Max receive count of message after which it's moved to dead letter queue
     * @default 3
     */
    readonly maxReceiveCount?: number;
    /**
     * Issue alarm when message is older than X seconds in queue
     */
    readonly alarmWhenMessageOlderThanSeconds: number;
    /**
     * Alarm to which send CloudWatch alarms/ok state changes
     */
    readonly alarmEmail: string;
}
export declare class MonitoredQueue extends cdk.Construct {
    /** @returns the Arn of the main queue */
    readonly queueArn: string;
    /** @returns the URL of the main queue */
    readonly queueUrl: string;
    /** @returns the name of the main queue */
    readonly queueName: string;
    /** @returns the Arn of the dead letter queue */
    readonly deadLetterQueueArn: string;
    /** @returns the URL of the dead letter queue */
    readonly deadLetterQueueUrl: string;
    /** @returns the name of the dead letter queue */
    readonly deadLetterQueueName: string;
    constructor(scope: cdk.Construct, id: string, props: MonitoredQueueProps);
}
